@@ -129,11 +129,11 @@ extern "C"
         return new(std::nothrow) apg::pattern(ppat->advance2(numgens, exponent));
     }
 
-    void* GetSolidForPattern(void* pat, uint64_t state) {
+    void* GetSolidForPattern(void* pat, uint64_t state, uint64_t exponent) {
         auto ppat = reinterpret_cast<apg::pattern*>(pat);
         auto lab = ppat->getlab();
         uint64_t depth = ppat->gethnode().depth;
-        return new(std::nothrow) apg::pattern(lab, lab->solid(depth, state), ppat->getrule());
+        return new(std::nothrow) apg::pattern(lab, lab->solid(depth, state << exponent), ppat->getrule());
     }
 
     void* GetSemisolidForPattern(void* pat, int flags) {
