@@ -67,10 +67,29 @@ class Pattern(object):
 
         return temp
 
-    def _solid(self, state):
+    def _solid(self, state, exponent=0):
 
-        newptr = self.lifelib('GetSolidForPattern', self.ptr, state)
-        return Pattern(self.session, newptr, self.owner)
+        if (state < 0) or (state >= (2**64)):
+            raise ValueError("States must be integers in the interval [0, 2^64 - 1].")
+
+        temp = self.owner.pattern("", self.getrule())
+
+        while (state != 0):
+
+            t = tzcount(state)
+            if (t > 0):
+                state = state >> t
+                exponent = exponent + t
+
+            max_num = 2 ** 30
+
+            x = int(state % max_num)
+
+            newptr = self.lifelib('GetSolidForPattern', self.ptr, x, exponent)
+            temp += Pattern(self.session, newptr, self.owner)
+            state = state - x
+
+        return temp
 
     def _semisolid(self, flags):
 
