@@ -12,8 +12,26 @@ class TestGoL(unittest.TestCase):
     def setUp(self):
 
         self.sess = lifelib.load_rules('b3s23')
-        self.lt = self.sess.lifetree(memory=1000) # , n_layers=1)
+        self.lt = self.sess.lifetree(memory=1000, n_layers=4)
 
+    def test_lhistory(self):
+
+        scorbie = self.lt.pattern('''x = 50, y = 72, rule = LifeHistory
+26.4B$25.4B$24.4B$19.3B.4B$18.8B10.E$18.7B.B7.3E$18.10B5.E$16.12B5.CE
+$15.14B.5B$15.18B$14.22B$14.23B$12.ECB.22B$11.E.EB.23B$11.E4.22B$10.
+2E5.20B$18.19B$17.21B$15.ECB.15B.4B$14.E.EB3.10B5.4B$14.E6.10B6.4B$
+13.2E5.13B5.4B$19.15B5.4B$18.16B6.4B$17.17B7.4B$18.16B8.4B$19.13B11.
+4B$19.5B2C2B.3B12.4B$21.3B2C2B2.4B11.4B$21.8B3.CE12.4B$20.8B4.E14.3B$
+20.8B5.3E12.2B$20.7B8.E13.B$20.7B$21.6B7.E$21.6B6.E.E$22.5B6.E.E$22.
+6B4.2E.3E$21.6B6.B4.E$21.7B3.B2CB3E$8.3B11.8B.B2C.E$7.6B9.10B$5.11B5.
+3B2C6B$5.10B2E5.2B2C6B$5.11BE5.10B$5.11BEBEB2.11B$5.12BECB.12B$5.13B.
+15B$5.11B3.16B$5.11B3.16B.2B$5.10B4.18BCE$5.6B7.17B.BCE$5.6B6.4B2.8B.
+4B.B$5.4B7.4B4.7B$5.3B7.4B5.6B$6.B7.4B6.4B$13.4B5.E3B$12.4B5.E.CB$11.
+4B6.E.C$10.3AB8.E$9.3BA6.3E$8.3BA7.E$7.4B$6.4B$5.4B$4.4B$3.4B$2.4B$.
+4B$4B$3B$2B!''')
+
+        self.assertEqual(scorbie[2000].population, 4425)
+ 
     def test_stream(self):
 
         push44 = [0, 109, 90, 93, 91, 90, 95, 91, 91, 138, 157, 96, 90, 120, 91, 97, 107, 90, 90, 93, 188]
